@@ -3,8 +3,9 @@
 #' @return values for font sizes
 #' @keywords internal
 sv_font_size_title <- function(mobile) {
+  # return(11)
   if (mobile == FALSE) return(11)
-  else if (mobile == TRUE) return(15)
+  else if (mobile == TRUE) return(16)
 }
 
 #' Get default font_size_body
@@ -12,6 +13,7 @@ sv_font_size_title <- function(mobile) {
 #' @return values for font sizes
 #' @keywords internal
 sv_font_size_body <- function(mobile) {
-  if (mobile == FALSE) font_size_body <- 10
-  else if (mobile == TRUE) font_size_body <- 14
+  # return(10)
+  if (mobile == FALSE) return(10)
+  else if (mobile == TRUE) return(15)
 }
