@@ -1,6 +1,6 @@
-#' @title Quick theme for a ggplot. 
+#' @title DEPRECATED Quick theme for a ggplot. 
 #'
-#' @description Quick theme for a ggplot visualisation.
+#' @description DEPRECATED Quick theme for a ggplot visualisation. 
 #' @param font The font for all text to use. Defaults to "".
 #' @param font_title The font for the title. If NULL, inherits from font argument.
 #' @param font_subtitle The font for the subtitle. If NULL, inherits from font argument.
@@ -57,6 +57,8 @@ gg_theme <-
            gridlines_h = NULL,
            void = FALSE) {
     
+    warning( "The `simplevis::gg_theme` function is deprecated as of {simplevis} 6.4.0. Please use the ggblanket::gg_theme function instead.")
+    
     if (!rlang::is_null(gridlines_v)) {
       x_grid <- gridlines_v
       warning( "The `gridlines_v` argument of `gg_theme()` is deprecated as of {simplevis} 6.3.0. Please use the `x_grid` argument instead.")
@@ -272,4 +274,4 @@ theme_mobile_extra <- function(void = FALSE) {
       legend.margin = margin(t = 0, b = 0, l = 0, r = 0)
     )
   }
-}
\ No newline at end of file
+}
