@@ -7,12 +7,13 @@
 #' @return A character vector of hex codes.
 #' @export
 #' @examples 
-#' scales::show_col(pal_d3_reorder(9)) 
-pal_d3_reorder <- function(n) {
+#' scales::show_col(pal_d3_mix(9)) 
+pal_d3_mix <- function(n) {
   
-  c("#17BECFFF", "#BCBD22FF", "#8C564BFF", "#E377C2FF", "#1F77B4FF", "#2CA02CFF", "#FF7F0EFF", "#9467BDFF", "#D62728FF")[1:n]
+  c("#17BECF", "#BCBD22", "#8C564B", "#E377C2", "#1F77B4", "#FF7F0E", "#2CA02C", "#9467BD", "#D62728")[1:n]
 }
 
+
 #' Viridis palette reordered.
 #' 
 #' @description A function to retreive a vector of hex codes for a numeric (or ordererd) variable.
@@ -22,8 +23,8 @@ pal_d3_reorder <- function(n) {
 #' @return A character vector of hex codes.
 #' @export 
 #' @examples 
-#' scales::show_col(pal_viridis_reorder(9)) 
-pal_viridis_reorder <- function(n) {
+#' scales::show_col(pal_viridis_mix(9)) 
+pal_viridis_mix <- function(n) {
   
   if(n == 1) viridis::viridis(4)[2]
   else if(n == 2) viridis::viridis(4)[c(2, 3)]
@@ -40,6 +41,6 @@ pal_viridis_reorder <- function(n) {
 #' @export 
 #' @examples 
 #' scales::show_col(pal_na()) 
-pal_na <- function(pal = "#7F7F7FFF") {
+pal_na <- function(pal = "#7F7F7F") {
   return(pal)  
 }
